==> antd-pro-toolkit-0.6.0.tgz: package/es/Uploader/index.js <==
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React, { Component } from 'react';
import { Upload, Modal, message, Icon, Button } from 'antd';
import File from './File';
import Image from './Image';
import _ from 'lodash';

var Uploader =
/*#__PURE__*/
function (_Component) {
  _inherits(Uploader, _Component);

  function Uploader(props) {
    var _this;

    _classCallCheck(this, Uploader);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Uploader).call(this, props));

    _this.getValue = function (value) {
      var fileList = [];

      if (Object.prototype.toString.call(value) === '[object Array]') {
        fileList = value.filter(function (item) {
          return !_.isEmpty(item);
        });
      }

      _this.setState({
        fileList: fileList
      });
    }; // 上传前校验文件格式和文件大小


    _this.beforeUpload = function (file) {
      var _this$props = _this.props,
          beforeUpload = _this$props.beforeUpload,
          maxFileSize = _this$props.maxFileSize;

      if (typeof beforeUpload === 'function') {
        return beforeUpload(file);
      } // 获取设置的可以上传的文件类型


      var accept = _this.props.uploadInfo.accept; // 将文件名按‘.’分割,倒序,然后取出首个,即为文件名,然后转小写

      var fileName = file.name.split('.').reverse()[0].toLowerCase(); // 判断当前上传的文件是否为允许的格式

      if (!accept.includes(fileName)) {
        message.error('文件格式不正确');
        return false;
      }

      if (maxFileSize) {
        var scaleOut = file.size / 1024 / 1024 <= Math.abs(maxFileSize);

        if (!scaleOut) {
          message.error("\u4E0A\u4F20\u6587\u4EF6\u5FC5\u987B\u5C0F\u4E8E".concat(maxFileSize, "MB!"));
          return false;
        }
      }

      return true;
    }; // 取消预览图片


    _this.handleCancel = function () {
      return _this.setState({
        previewVisible: false,
        previewImage: {
          id: '',
          name: '',
          originPath: '',
          path: '',
          thumbnailPath: '',
          type: ''
        }
      });
    }; // 预览图片


    _this.handlePreview = function (item) {
      // 判断文件类型,目前只有图片类型和pdf可以预览
      var fileType = item.name.split('.').reverse()[0].toLowerCase();
      var imgType = ['jpg', 'jpeg', 'png', 'pdf'];
      var canPreview = imgType.includes(fileType);
      if (!canPreview) return message.error("\u6682\u4E0D\u652F\u6301\u9884\u89C8".concat(fileType, "\u683C\u5F0F\u7684\u6587\u4EF6"));

      _this.setState({
        previewImage: item,
        previewVisible: true,
        previewType: fileType
      });
    };

    _this.handleChange = function (info) {
      var _this$props2 = _this.props,
          onChange = _this$props2.onChange,
          alwaysShowUploadButton = _this$props2.alwaysShowUploadButton,
          _this$props2$max = _this$props2.max,
          max = _this$props2$max === void 0 ? 9999 : _this$props2$max;
      var fileList = _this.state.fileList;

      if ('uploading' === info.file.status) {
        _this.setState({
          fileUploading: true
        });

        return;
      }

      if ('done' === info.file.status) {
        if (info.file.response.errorCode === 0) {
          var fileResultList = []; // 如果始终显示上传按钮,则表明会存在上传数量大于max的情况

          if (alwaysShowUploadButton) {
            if (fileList.length === max) {
              fileResultList = [].concat(_toConsumableArray(fileList.filter(function (_, index) {
                return index !== 0;
              })), [info.file.response.data]);
            } else {
              fileResultList = [].concat(_toConsumableArray(fileList), [info.file.response.data]);
            }
          } else {
            fileResultList = [].concat(_toConsumableArray(fileList), [info.file.response.data]);
          }

          _this.setState({
            fileUploading: false,
            fileList: fileResultList
          });

          if (onChange) {
            onChange(fileResultList);
          }
        } else {
          _this.setState({
            fileUploading: false
          });

          message.error(info.file.response.msg);
        }
      }
    }; // 删除文件


    _this.handleRemoveFile = function (file) {
      var onChange = _this.props.onChange;
      var fileList = _this.state.fileList;

      _this.setState({
        fileList: fileList.filter(function (item) {
          return item.id !== file.id;
        })
      });

      if (onChange) {
        onChange(fileList.filter(function (item) {
          return item.id !== file.id;
        }));
      }
    };

    _this.state = {
      // 是否打开预览图片modal
      previewVisible: false,
      // 预览的图片对象
      previewImage: {
        id: '',
        name: '',
        originPath: '',
        path: '',
        thumbnailPath: '',
        type: ''
      },
      // 预览图片的类型
      previewType: '',
      // 是否正在上传文件
      fileUploading: false,
      // 已有的文件列表
      fileList: [],
      // 组件宽度
      width: 300
    };
    return _this;
  }

  _createClass(Uploader, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      // 获取文件列表
      var value = this.props.value; // 获取设置的宽度

      var width = this.props.width; // 如果没有设置宽度,就获取元素的宽度

      var currentWidth = width ? width : this.refs.file.clientWidth;
      this.setState({
        width: currentWidth
      });
      this.getValue(value);
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      this.getValue(nextProps.value);
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props3 = this.props,
          uploadInfo = _this$props3.uploadInfo,
          _this$props3$isView = _this$props3.isView,
          isView = _this$props3$isView === void 0 ? false : _this$props3$isView,
          _this$props3$type = _this$props3.type,
          type = _this$props3$type === void 0 ? 'card' : _this$props3$type,
          style = _this$props3.style,
          _this$props3$max = _this$props3.max,
          max = _this$props3$max === void 0 ? 9999 : _this$props3$max,
          _this$props3$placehol = _this$props3.placeholder,
          placeholder = _this$props3$placehol === void 0 ? '' : _this$props3$placehol,
          _this$props3$showResu = _this$props3.showResult,
          showResult = _this$props3$showResu === void 0 ? true : _this$props3$showResu,
          _this$props3$alwaysSh = _this$props3.alwaysShowUploadButton,
          alwaysShowUploadButton = _this$props3$alwaysSh === void 0 ? false : _this$props3$alwaysSh;
      var _this$state = this.state,
          previewVisible = _this$state.previewVisible,
          previewImage = _this$state.previewImage,
          fileUploading = _this$state.fileUploading,
          fileList = _this$state.fileList,
          width = _this$state.width,
          previewType = _this$state.previewType;
      var renderImageList = type === 'card' && fileList.map(function (item) {
        return React.createElement(Image, {
          isUploading: !isView,
          key: item.id,
          item: item,
          handlePreview: _this2.handlePreview,
          handleRemove: _this2.handleRemoveFile
        });
      });
      var renderFileList = type === 'list' && fileList.map(function (item) {
        return React.createElement(File, {
          width: width,
          isUploading: !isView,
          key: item.id,
          item: item,
          handlePreview: _this2.handlePreview,
          handleRemove: _this2.handleRemoveFile
        });
      });

      if (type === 'card') {
        this.listType = {
          listType: 'picture-card'
        };
      }

      var UploadRender = null;
      var UploadButton = type === 'card' ? React.createElement("div", null, React.createElement(Icon, {
        type: fileUploading ? 'loading' : 'plus'
      }), placeholder && React.createElement("div", {
        className: "ant-upload-text"
      }, placeholder)) : React.createElement(Button, null, React.createElement(Icon, {
        type: fileUploading ? 'loading' : 'paper-clip'
      }), " ", placeholder ? placeholder : '上传');

      if (!isView) {
        if (alwaysShowUploadButton) {
          UploadRender = UploadButton;
        } else {
          if (max - fileList.length !== 0) {
            UploadRender = UploadButton;
          }
        }
      }

      return React.createElement("div", {
        style: _extends(_extends({}, style), {
          width: width
        }),
        ref: 'file'
      }, showResult && renderImageList, React.createElement(Upload, _extends({}, uploadInfo, this.listType, {
        showUploadList: false,
        beforeUpload: this.beforeUpload,
        onChange: this.handleChange,
        disabled: fileUploading
      }), UploadRender), showResult && renderFileList, React.createElement(Modal, {
        maskClosable: false,
        keyboard: false,
        visible: previewVisible,
        footer: null,
        onCancel: this.handleCancel,
        width: 800,
        bodyStyle: {
          padding: '40px'
        },
        title: previewImage.name
      }, previewType !== 'pdf' && React.createElement("img", {
        alt: previewImage.name,
        style: {
          width: '100%'
        },
        src: (previewImage.path || '').replace('_150x150', '')
      }), previewType === 'pdf' && React.createElement("iframe", {
        style: {
          width: '100%',
          height: '800px'
        },
        src: previewImage.path,
        title: previewImage.name
      })));
    }
  }]);

  return Uploader;
}(Component);

export { Uploader as default };

==> antd-pro-toolkit-0.6.8.tgz: package/es/Uploader/index.js <==
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React, { Component } from 'react';
import { Upload, Modal, message, Button } from 'antd';
import { LoadingOutlined, PaperClipOutlined, PlusOutlined } from '@ant-design/icons';
import File from './File';
import Image from './Image';
import _ from 'lodash';

var Uploader =
/*#__PURE__*/
function (_Component) {
  _inherits(Uploader, _Component);

  function Uploader(props) {
    var _this;

    _classCallCheck(this, Uploader);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Uploader).call(this, props));

    _this.getValue = function (value) {
      var fileList = [];

      if (Object.prototype.toString.call(value) === '[object Array]') {
        fileList = value.filter(function (item) {
          return !_.isEmpty(item);
        });
      }

      _this.setState({
        fileList: fileList
      });
    }; // 上传前校验文件格式和文件大小


    _this.beforeUpload = function (file) {
      var _this$props = _this.props,
          beforeUpload = _this$props.beforeUpload,
          maxFileSize = _this$props.maxFileSize;

      if (typeof beforeUpload === 'function') {
        return beforeUpload(file);
      } // 获取设置的可以上传的文件类型


      var accept = _this.props.uploadInfo.accept; // 将文件名按‘.’分割,倒序,然后取出首个,即为文件名,然后转小写

      var fileName = file.name.split('.').reverse()[0].toLowerCase(); // 判断当前上传的文件是否为允许的格式

      if (!accept.includes(fileName)) {
        message.error('文件格式不正确');
        return false;
      }

      if (maxFileSize) {
        var scaleOut = file.size / 1024 / 1024 <= Math.abs(maxFileSize);

        if (!scaleOut) {
          message.error("\u4E0A\u4F20\u6587\u4EF6\u5FC5\u987B\u5C0F\u4E8E".concat(maxFileSize, "MB!"));
          return false;
        }
      }

      return true;
    }; // 取消预览图片


    _this.handleCancel = function () {
      return _this.setState({
        previewVisible: false,
        previewImage: {
          id: '',
          name: '',
          originPath: '',
          path: '',
          thumbnailPath: '',
          type: ''
        }
      });
    }; // 预览图片


    _this.handlePreview = function (item) {
      // 判断文件类型,目前只有图片类型和pdf可以预览
      var fileType = item.name.split('.').reverse()[0].toLowerCase();
      var imgType = ['jpg', 'jpeg', 'png', 'pdf'];
      var canPreview = imgType.includes(fileType);
      if (!canPreview) return message.error("\u6682\u4E0D\u652F\u6301\u9884\u89C8".concat(fileType, "\u683C\u5F0F\u7684\u6587\u4EF6"));

      _this.setState({
        previewImage: item,
        previewVisible: true,
        previewType: fileType
      });
    };

    _this.handleChange = function (info) {
      var _this$props2 = _this.props,
          onChange = _this$props2.onChange,
          alwaysShowUploadButton = _this$props2.alwaysShowUploadButton,
          _this$props2$max = _this$props2.max,
          max = _this$props2$max === void 0 ? 9999 : _this$props2$max;
      var fileList = _this.state.fileList;

      if ('uploading' === info.file.status) {
        _this.setState({
          fileUploading: true
        });

        return;
      }

      if ('done' === info.file.status) {
        var data = info.file.response.data.fileResult ? info.file.response.data.fileResult : info.file.response.data;

        if (info.file.response.errorCode === 0) {
          var fileResultList = []; // 如果始终显示上传按钮,则表明会存在上传数量大于max的情况

          if (alwaysShowUploadButton) {
            if (fileList.length === max) {
              fileResultList = [].concat(_toConsumableArray(fileList.filter(function (_, index) {
                return index !== 0;
              })), [data]);
            } else {
              fileResultList = [].concat(_toConsumableArray(fileList), [data]);
            }
          } else {
            fileResultList = [].concat(_toConsumableArray(fileList), [data]);
          }

          _this.setState({
            fileUploading: false,
            fileList: fileResultList
          });

          if (onChange) {
            onChange(fileResultList, info.file.response.data);
          }
        } else {
          _this.setState({
            fileUploading: false
          });

          message.error(info.file.response.msg);
        }
      }
    }; // 删除文件


    _this.handleRemoveFile = function (file) {
      var onChange = _this.props.onChange;
      var fileList = _this.state.fileList;

      _this.setState({
        fileList: fileList.filter(function (item) {
          return item.id !== file.id;
        })
      });

      if (onChange) {
        onChange(fileList.filter(function (item) {
          return item.id !== file.id;
        }));
      }
    };

    _this.state = {
      // 是否打开预览图片modal
      previewVisible: false,
      // 预览的图片对象
      previewImage: {
        id: '',
        name: '',
        originPath: '',
        path: '',
        thumbnailPath: '',
        type: ''
      },
      // 预览图片的类型
      previewType: '',
      // 是否正在上传文件
      fileUploading: false,
      // 已有的文件列表
      fileList: [],
      // 组件宽度
      width: 300
    };
    return _this;
  }

  _createClass(Uploader, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      // 获取文件列表
      var value = this.props.value; // 获取设置的宽度

      var width = this.props.width; // 如果没有设置宽度,就获取元素的宽度

      var currentWidth = width ? width : this.refs.file.clientWidth;
      this.setState({
        width: currentWidth
      });
      this.getValue(value);
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      this.getValue(nextProps.value);
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props3 = this.props,
          uploadInfo = _this$props3.uploadInfo,
          _this$props3$isView = _this$props3.isView,
          isView = _this$props3$isView === void 0 ? false : _this$props3$isView,
          _this$props3$type = _this$props3.type,
          type = _this$props3$type === void 0 ? 'card' : _this$props3$type,
          style = _this$props3.style,
          _this$props3$max = _this$props3.max,
          max = _this$props3$max === void 0 ? 9999 : _this$props3$max,
          _this$props3$placehol = _this$props3.placeholder,
          placeholder = _this$props3$placehol === void 0 ? '' : _this$props3$placehol,
          _this$props3$showResu = _this$props3.showResult,
          showResult = _this$props3$showResu === void 0 ? true : _this$props3$showResu,
          _this$props3$alwaysSh = _this$props3.alwaysShowUploadButton,
          alwaysShowUploadButton = _this$props3$alwaysSh === void 0 ? false : _this$props3$alwaysSh;
      var _this$state = this.state,
          previewVisible = _this$state.previewVisible,
          previewImage = _this$state.previewImage,
          fileUploading = _this$state.fileUploading,
          fileList = _this$state.fileList,
          width = _this$state.width,
          previewType = _this$state.previewType;
      var renderImageList = type === 'card' && fileList.map(function (item) {
        return React.createElement(Image, {
          isUploading: !isView,
          key: item.id,
          item: item,
          handlePreview: _this2.handlePreview,
          handleRemove: _this2.handleRemoveFile
        });
      });
      var renderFileList = type === 'list' && fileList.map(function (item) {
        return React.createElement(File, {
          width: width,
          isUploading: !isView,
          key: item.id,
          item: item,
          handlePreview: _this2.handlePreview,
          handleRemove: _this2.handleRemoveFile
        });
      });

      if (type === 'card') {
        this.listType = {
          listType: 'picture-card'
        };
      }

      var UploadRender = null;
      var UploadButton = type === 'card' ? React.createElement("div", null, fileUploading ? React.createElement(LoadingOutlined, null) : React.createElement(PlusOutlined, null), placeholder && React.createElement("div", {
        className: "ant-upload-text"
      }, placeholder)) : React.createElement(Button, null, fileUploading ? React.createElement(LoadingOutlined, null) : React.createElement(PaperClipOutlined, null), placeholder ? placeholder : '上传');

      if (!isView) {
        if (alwaysShowUploadButton) {
          UploadRender = UploadButton;
        } else {
          if (max - fileList.length !== 0) {
            UploadRender = UploadButton;
          }
        }
      }

      return React.createElement("div", {
        style: _extends(_extends({}, style), {
          width: width
        }),
        ref: 'file'
      }, showResult && renderImageList, React.createElement(Upload, _extends({}, uploadInfo, this.listType, {
        showUploadList: false,
        beforeUpload: this.beforeUpload,
        onChange: this.handleChange,
        disabled: fileUploading
      }), UploadRender), showResult && renderFileList, React.createElement(Modal, {
        maskClosable: false,
        keyboard: false,
        visible: previewVisible,
        footer: null,
        onCancel: this.handleCancel,
        width: 800,
        bodyStyle: {
          padding: '40px'
        },
        title: previewImage.name
      }, previewType !== 'pdf' && React.createElement("img", {
        alt: previewImage.name,
        style: {
          width: '100%'
        },
        src: (previewImage.path || '').replace('_150x150', '')
      }), previewType === 'pdf' && React.createElement("iframe", {
        style: {
          width: '100%',
          height: '800px'
        },
        src: previewImage.path,
        title: previewImage.name
      })));
    }
  }]);

  return Uploader;
}(Component);

export { Uploader as default };
